# @summary 
#    Ensure message of the day is configured properly (Scored)
#
# The contents of the /etc/motd file are displayed to users after login and function as a message of the day for 
# authenticated users.
# Unix-based systems have typically displayed information about the OS release and patch level upon logging in to 
# the system. This information can be useful to developers who are developing software for a particular OS platform. 
# If mingetty(8) supports the following options, they display operating system information: \m - machine 
# architecture \r - operating system release \s - operating system name \v - operating system version
#
# Rationale:
# Warning messages inform users who are attempting to login to the system of their legal status regarding the 
# system and must include the name of the organization that owns the system and any monitoring policies that 
# are in place. Displaying OS and patch level information in login banners also has the side effect of providing 
# detailed system information to attackers attempting to target specific exploits of a system. Authorized users 
# can easily get this information by running the " uname -a " command once they have logged in.
#
# @param enforce
#    Enforce the rule or just test and log
#
# @param message
#    Message to print into the log
#
# @param log_level
#    The log_level for the above message
#
# @example
#   class security_baseline::rules::common::sec_motd {
#       enforce => true,
#       message => 'Test',
#       log_level => 'info'
#   }
#
# @api private
class security_baseline::rules::common::sec_motd (
  Boolean $enforce = true,
  String $message = '',
  String $log_level = ''
) {
    if($facts['security_baseline']['motd']['content'] != '') {
      echo { 'motd':
        message  => $message,
        loglevel => $log_level,
        withpath => false,
      }
    }
  }
